diff --git a/openrtx/include/fonts/symbols/sources/access-point.svg b/openrtx/include/fonts/symbols/sources/access-point.svg
new file mode 100644
index 00000000..77988f4c
--- /dev/null
+++ b/openrtx/include/fonts/symbols/sources/access-point.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/openrtx/include/fonts/symbols/sources/call-made.svg b/openrtx/include/fonts/symbols/sources/call-made.svg
new file mode 100644
index 00000000..a3c17841
--- /dev/null
+++ b/openrtx/include/fonts/symbols/sources/call-made.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/openrtx/include/fonts/symbols/sources/call-received.svg b/openrtx/include/fonts/symbols/sources/call-received.svg
new file mode 100644
index 00000000..7af137f1
--- /dev/null
+++ b/openrtx/include/fonts/symbols/sources/call-received.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/openrtx/include/fonts/symbols/sources/network.svg b/openrtx/include/fonts/symbols/sources/network.svg
new file mode 100644
index 00000000..e61d7337
--- /dev/null
+++ b/openrtx/include/fonts/symbols/sources/network.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/openrtx/include/fonts/symbols/sources/transmission-tower.svg b/openrtx/include/fonts/symbols/sources/transmission-tower.svg
new file mode 100644
index 00000000..de42948b
--- /dev/null
+++ b/openrtx/include/fonts/symbols/sources/transmission-tower.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/openrtx/include/fonts/symbols/symbols.h b/openrtx/include/fonts/symbols/symbols.h
index 9d624ce3..55d32813 100644
--- a/openrtx/include/fonts/symbols/symbols.h
+++ b/openrtx/include/fonts/symbols/symbols.h
@@ -1,13 +1,18 @@
// This is a generated file, please do not edit it! Use generate_symbols.py
typedef enum {
SYMBOL_SPACE = 32,
- SYMBOL_ALPHA_M_BOX_OUTLINE = 33,
- SYMBOL_COG = 34,
- SYMBOL_CROSSHAIRS_GPS = 35,
- SYMBOL_CROSSHAIRS = 36,
- SYMBOL_LOCK = 37,
- SYMBOL_WIFI_STRENGTH_1 = 38,
- SYMBOL_WIFI_STRENGTH_2 = 39,
- SYMBOL_WIFI_STRENGTH_3 = 40,
- SYMBOL_WIFI_STRENGTH_4 = 41,
+ SYMBOL_ACCESS_POINT = 33,
+ SYMBOL_ALPHA_M_BOX_OUTLINE = 34,
+ SYMBOL_CALL_MADE = 35,
+ SYMBOL_CALL_RECEIVED = 36,
+ SYMBOL_COG = 37,
+ SYMBOL_CROSSHAIRS_GPS = 38,
+ SYMBOL_CROSSHAIRS = 39,
+ SYMBOL_LOCK = 40,
+ SYMBOL_NETWORK = 41,
+ SYMBOL_TRANSMISSION_TOWER = 42,
+ SYMBOL_WIFI_STRENGTH_1 = 43,
+ SYMBOL_WIFI_STRENGTH_2 = 44,
+ SYMBOL_WIFI_STRENGTH_3 = 45,
+ SYMBOL_WIFI_STRENGTH_4 = 46,
} symbol_t;
diff --git a/openrtx/include/fonts/symbols/Symbols5pt7b.h b/openrtx/include/fonts/symbols/Symbols5pt7b.h
index 1a77e572..2a0a4450 100644
--- a/openrtx/include/fonts/symbols/Symbols5pt7b.h
+++ b/openrtx/include/fonts/symbols/Symbols5pt7b.h
@@ -1,11 +1,16 @@
// This is a generated file, please do not edit it! Use generate_symbols.py
static const uint8_t Symbols5pt7bBitmaps[] PROGMEM = {
0x00, //space
+0x00, 0x00, 0x42, 0x24, 0x24, 0x42, 0x00, 0x00, //access-point.svg
0x00, 0x7e, 0x5a, 0x66, 0x66, 0x42, 0x7e, 0x00, //alpha-m-box-outline.svg
+0x00, 0x00, 0x04, 0x08, 0x10, 0x20, 0x00, 0x00, //call-made.svg
+0x00, 0x00, 0x04, 0x08, 0x10, 0x20, 0x00, 0x00, //call-received.svg
0x00, 0x18, 0x7e, 0x66, 0x66, 0x7e, 0x18, 0x00, //cog.svg
0x00, 0x3c, 0x42, 0x5a, 0x5a, 0x42, 0x3c, 0x00, //crosshairs-gps.svg
0x00, 0x3c, 0x42, 0x42, 0x42, 0x42, 0x3c, 0x00, //crosshairs.svg
0x18, 0x24, 0x24, 0x7e, 0x7e, 0x7e, 0x7e, 0x00, //lock.svg
+0x00, 0x3c, 0x3c, 0x3c, 0x3c, 0x3c, 0x18, 0x18, //network.svg
+0x00, 0x00, 0x18, 0x18, 0x18, 0x18, 0x24, 0x00, //transmission-tower.svg
0x00, 0x3c, 0x81, 0x42, 0x3c, 0x18, 0x18, 0x00, //wifi-strength-1.svg
0x00, 0x3c, 0x81, 0x5a, 0x3c, 0x18, 0x18, 0x00, //wifi-strength-2.svg
0x00, 0x3c, 0x81, 0x7e, 0x3c, 0x18, 0x18, 0x00, //wifi-strength-3.svg
@@ -15,18 +20,23 @@ static const uint8_t Symbols5pt7bBitmaps[] PROGMEM = {
static const GFXglyph Symbols5pt7bGlyphs[] PROGMEM = {
//Index, W, H,xAdv,dX, dY
{ 0, 1, 1, 5, 0, -7}, // " " space
-{ 1, 8, 8, 5, 0, -7}, // "!" alpha-m-box-outline.svg
-{ 9, 8, 8, 5, 0, -7}, // """ cog.svg
-{ 17, 8, 8, 5, 0, -7}, // "#" crosshairs-gps.svg
-{ 25, 8, 8, 5, 0, -7}, // "$" crosshairs.svg
-{ 33, 8, 8, 5, 0, -7}, // "%" lock.svg
-{ 41, 8, 8, 5, 0, -7}, // "&" wifi-strength-1.svg
-{ 49, 8, 8, 5, 0, -7}, // "'" wifi-strength-2.svg
-{ 57, 8, 8, 5, 0, -7}, // "(" wifi-strength-3.svg
-{ 65, 8, 8, 5, 0, -7}, // ")" wifi-strength-4.svg
+{ 1, 8, 8, 5, 0, -7}, // "!" access-point.svg
+{ 9, 8, 8, 5, 0, -7}, // """ alpha-m-box-outline.svg
+{ 17, 8, 8, 5, 0, -7}, // "#" call-made.svg
+{ 25, 8, 8, 5, 0, -7}, // "$" call-received.svg
+{ 33, 8, 8, 5, 0, -7}, // "%" cog.svg
+{ 41, 8, 8, 5, 0, -7}, // "&" crosshairs-gps.svg
+{ 49, 8, 8, 5, 0, -7}, // "'" crosshairs.svg
+{ 57, 8, 8, 5, 0, -7}, // "(" lock.svg
+{ 65, 8, 8, 5, 0, -7}, // ")" network.svg
+{ 73, 8, 8, 5, 0, -7}, // "*" transmission-tower.svg
+{ 81, 8, 8, 5, 0, -7}, // "+" wifi-strength-1.svg
+{ 89, 8, 8, 5, 0, -7}, // "," wifi-strength-2.svg
+{ 97, 8, 8, 5, 0, -7}, // "-" wifi-strength-3.svg
+{ 105, 8, 8, 5, 0, -7}, // "." wifi-strength-4.svg
};
static const GFXfont Symbols5pt7b PROGMEM = {
(uint8_t *)Symbols5pt7bBitmaps,
(GFXglyph *)Symbols5pt7bGlyphs,
//ASCII start, ASCII stop,y Advance
- 32, 41, 19 };
+ 32, 46, 19 };
diff --git a/openrtx/include/fonts/symbols/Symbols6pt7b.h b/openrtx/include/fonts/symbols/Symbols6pt7b.h
index 65b45cbc..a57f1afa 100644
--- a/openrtx/include/fonts/symbols/Symbols6pt7b.h
+++ b/openrtx/include/fonts/symbols/Symbols6pt7b.h
@@ -1,11 +1,16 @@
// This is a generated file, please do not edit it! Use generate_symbols.py
static const uint8_t Symbols6pt7bBitmaps[] PROGMEM = {
0x00, //space
+0x00, 0x00, 0x00, 0x01, 0x02, 0x4c, 0x93, 0x24, 0x08, 0x00, 0x00, 0x00, 0x00, //access-point.svg
0x00, 0x0f, 0xc4, 0x09, 0x7a, 0x52, 0x94, 0xa5, 0x29, 0x02, 0x3f, 0x00, 0x00, //alpha-m-box-outline.svg
+0x00, 0x00, 0x00, 0xf0, 0x0c, 0x05, 0x02, 0x41, 0x00, 0x80, 0x00, 0x00, 0x00, //call-made.svg
+0x00, 0x00, 0x00, 0x10, 0x08, 0x24, 0x0a, 0x03, 0x00, 0xf0, 0x00, 0x00, 0x00, //call-received.svg
0x00, 0x03, 0x03, 0xf1, 0xfe, 0x33, 0x0c, 0xc7, 0xf8, 0xfc, 0x0c, 0x00, 0x00, //cog.svg
0x00, 0x03, 0x03, 0x30, 0xb4, 0x5e, 0x97, 0xa2, 0xd0, 0xcc, 0x0c, 0x00, 0x00, //crosshairs-gps.svg
0x00, 0x03, 0x03, 0x30, 0x84, 0x40, 0x90, 0x22, 0x10, 0xcc, 0x0c, 0x00, 0x00, //crosshairs.svg
0x0c, 0x04, 0x81, 0x20, 0xfc, 0x3f, 0x0f, 0xc3, 0x30, 0xfc, 0x3f, 0x00, 0x00, //lock.svg
+0x00, 0x0f, 0xc3, 0xf0, 0xfc, 0x3f, 0x0f, 0xc3, 0xf0, 0x00, 0x7f, 0x83, 0x00, //network.svg
+0x00, 0x07, 0x80, 0xc0, 0xfc, 0x00, 0x03, 0x01, 0xe0, 0x48, 0x12, 0x00, 0x00, //transmission-tower.svg
0x00, 0x07, 0x86, 0x19, 0x02, 0x40, 0x8b, 0x41, 0xe0, 0x30, 0x00, 0x00, 0x00, //wifi-strength-1.svg
0x00, 0x07, 0x86, 0x19, 0x02, 0x7f, 0x8f, 0xc1, 0xe0, 0x30, 0x00, 0x00, 0x00, //wifi-strength-2.svg
0x00, 0x07, 0x86, 0x19, 0x32, 0x7f, 0x8f, 0xc1, 0xe0, 0x30, 0x00, 0x00, 0x00, //wifi-strength-3.svg
@@ -15,18 +20,23 @@ static const uint8_t Symbols6pt7bBitmaps[] PROGMEM = {
static const GFXglyph Symbols6pt7bGlyphs[] PROGMEM = {
//Index, W, H,xAdv,dX, dY
{ 0, 1, 1, 6, 0, -8}, // " " space
-{ 1, 10, 10, 6, 0, -8}, // "!" alpha-m-box-outline.svg
-{ 14, 10, 10, 6, 0, -8}, // """ cog.svg
-{ 27, 10, 10, 6, 0, -8}, // "#" crosshairs-gps.svg
-{ 40, 10, 10, 6, 0, -8}, // "$" crosshairs.svg
-{ 53, 10, 10, 6, 0, -8}, // "%" lock.svg
-{ 66, 10, 10, 6, 0, -8}, // "&" wifi-strength-1.svg
-{ 79, 10, 10, 6, 0, -8}, // "'" wifi-strength-2.svg
-{ 92, 10, 10, 6, 0, -8}, // "(" wifi-strength-3.svg
-{ 105, 10, 10, 6, 0, -8}, // ")" wifi-strength-4.svg
+{ 1, 10, 10, 6, 0, -8}, // "!" access-point.svg
+{ 14, 10, 10, 6, 0, -8}, // """ alpha-m-box-outline.svg
+{ 27, 10, 10, 6, 0, -8}, // "#" call-made.svg
+{ 40, 10, 10, 6, 0, -8}, // "$" call-received.svg
+{ 53, 10, 10, 6, 0, -8}, // "%" cog.svg
+{ 66, 10, 10, 6, 0, -8}, // "&" crosshairs-gps.svg
+{ 79, 10, 10, 6, 0, -8}, // "'" crosshairs.svg
+{ 92, 10, 10, 6, 0, -8}, // "(" lock.svg
+{ 105, 10, 10, 6, 0, -8}, // ")" network.svg
+{ 118, 10, 10, 6, 0, -8}, // "*" transmission-tower.svg
+{ 131, 10, 10, 6, 0, -8}, // "+" wifi-strength-1.svg
+{ 144, 10, 10, 6, 0, -8}, // "," wifi-strength-2.svg
+{ 157, 10, 10, 6, 0, -8}, // "-" wifi-strength-3.svg
+{ 170, 10, 10, 6, 0, -8}, // "." wifi-strength-4.svg
};
static const GFXfont Symbols6pt7b PROGMEM = {
(uint8_t *)Symbols6pt7bBitmaps,
(GFXglyph *)Symbols6pt7bGlyphs,
//ASCII start, ASCII stop,y Advance
- 32, 41, 22 };
+ 32, 46, 22 };
diff --git a/openrtx/include/fonts/symbols/Symbols8pt7b.h b/openrtx/include/fonts/symbols/Symbols8pt7b.h
index 6ef5339b..24876df1 100644
--- a/openrtx/include/fonts/symbols/Symbols8pt7b.h
+++ b/openrtx/include/fonts/symbols/Symbols8pt7b.h
@@ -1,11 +1,16 @@
// This is a generated file, please do not edit it! Use generate_symbols.py
static const uint8_t Symbols8pt7bBitmaps[] PROGMEM = {
0x00, //space
+0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x46, 0x03, 0x2d, 0x69, 0x5d, 0x4b, 0x5a, 0x60, 0x31, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //access-point.svg
0x00, 0x00, 0x00, 0x0f, 0xf8, 0x40, 0x42, 0xfa, 0x15, 0x50, 0xaa, 0x85, 0x54, 0x2a, 0xa1, 0x01, 0x0f, 0xf8, 0x00, 0x00, 0x00, 0x00, //alpha-m-box-outline.svg
+0x00, 0x00, 0x00, 0x00, 0x00, 0x0f, 0x80, 0x0c, 0x00, 0xa0, 0x09, 0x00, 0x88, 0x08, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //call-made.svg
+0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x08, 0x08, 0x80, 0x48, 0x02, 0x80, 0x18, 0x00, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, //call-received.svg
0x00, 0x00, 0x38, 0x01, 0xc0, 0x7f, 0xc7, 0xff, 0x1c, 0x70, 0xe3, 0x87, 0x1c, 0x7f, 0xf1, 0xff, 0x01, 0xc0, 0x0e, 0x00, 0x00, 0x00, //cog.svg
0x00, 0x00, 0x10, 0x03, 0xe0, 0x20, 0x82, 0x22, 0x13, 0x91, 0xbe, 0xc4, 0xe4, 0x22, 0x20, 0x82, 0x03, 0xe0, 0x04, 0x00, 0x00, 0x00, //crosshairs-gps.svg
0x00, 0x00, 0x10, 0x03, 0xe0, 0x20, 0x82, 0x02, 0x10, 0x11, 0x80, 0xc4, 0x04, 0x20, 0x20, 0x82, 0x03, 0xe0, 0x04, 0x00, 0x00, 0x00, //crosshairs.svg
0x00, 0x00, 0x7c, 0x02, 0x20, 0x11, 0x01, 0xfc, 0x1f, 0xf0, 0xff, 0x87, 0xbc, 0x3d, 0xe1, 0xff, 0x0f, 0xf8, 0x7f, 0xc0, 0x00, 0x00, //lock.svg
+0x00, 0x00, 0x00, 0x07, 0xf0, 0x3f, 0x81, 0xfc, 0x0f, 0xe0, 0x7f, 0x03, 0xf8, 0x1f, 0xc0, 0x10, 0x01, 0xc0, 0xff, 0xe0, 0x00, 0x00, //network.svg
+0x00, 0x00, 0x7c, 0x02, 0x20, 0x04, 0x01, 0xfc, 0x18, 0x30, 0x14, 0x00, 0xe0, 0x0f, 0x80, 0x6c, 0x02, 0x20, 0x11, 0x00, 0x00, 0x00, //transmission-tower.svg
0x00, 0x00, 0x00, 0x0f, 0xf8, 0xc0, 0x64, 0x01, 0x10, 0x10, 0xc1, 0x83, 0xf8, 0x0f, 0x80, 0x38, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, //wifi-strength-1.svg
0x00, 0x00, 0x00, 0x0f, 0xf8, 0xc0, 0x64, 0x01, 0x11, 0x10, 0xff, 0x83, 0xf8, 0x0f, 0x80, 0x38, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, //wifi-strength-2.svg
0x00, 0x00, 0x00, 0x0f, 0xf8, 0xc0, 0x64, 0x71, 0x1f, 0xf0, 0xff, 0x83, 0xf8, 0x0f, 0x80, 0x38, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, //wifi-strength-3.svg
@@ -15,18 +20,23 @@ static const uint8_t Symbols8pt7bBitmaps[] PROGMEM = {
static const GFXglyph Symbols8pt7bGlyphs[] PROGMEM = {
//Index, W, H,xAdv,dX, dY
{ 0, 1, 1, 9, 0, -11}, // " " space
-{ 1, 13, 13, 9, 0, -11}, // "!" alpha-m-box-outline.svg
-{ 23, 13, 13, 9, 0, -11}, // """ cog.svg
-{ 45, 13, 13, 9, 0, -11}, // "#" crosshairs-gps.svg
-{ 67, 13, 13, 9, 0, -11}, // "$" crosshairs.svg
-{ 89, 13, 13, 9, 0, -11}, // "%" lock.svg
-{ 111, 13, 13, 9, 0, -11}, // "&" wifi-strength-1.svg
-{ 133, 13, 13, 9, 0, -11}, // "'" wifi-strength-2.svg
-{ 155, 13, 13, 9, 0, -11}, // "(" wifi-strength-3.svg
-{ 177, 13, 13, 9, 0, -11}, // ")" wifi-strength-4.svg
+{ 1, 13, 13, 9, 0, -11}, // "!" access-point.svg
+{ 23, 13, 13, 9, 0, -11}, // """ alpha-m-box-outline.svg
+{ 45, 13, 13, 9, 0, -11}, // "#" call-made.svg
+{ 67, 13, 13, 9, 0, -11}, // "$" call-received.svg
+{ 89, 13, 13, 9, 0, -11}, // "%" cog.svg
+{ 111, 13, 13, 9, 0, -11}, // "&" crosshairs-gps.svg
+{ 133, 13, 13, 9, 0, -11}, // "'" crosshairs.svg
+{ 155, 13, 13, 9, 0, -11}, // "(" lock.svg
+{ 177, 13, 13, 9, 0, -11}, // ")" network.svg
+{ 199, 13, 13, 9, 0, -11}, // "*" transmission-tower.svg
+{ 221, 13, 13, 9, 0, -11}, // "+" wifi-strength-1.svg
+{ 243, 13, 13, 9, 0, -11}, // "," wifi-strength-2.svg
+{ 265, 13, 13, 9, 0, -11}, // "-" wifi-strength-3.svg
+{ 287, 13, 13, 9, 0, -11}, // "." wifi-strength-4.svg
};
static const GFXfont Symbols8pt7b PROGMEM = {
(uint8_t *)Symbols8pt7bBitmaps,
(GFXglyph *)Symbols8pt7bGlyphs,
//ASCII start, ASCII stop,y Advance
- 32, 41, 30 };
+ 32, 46, 30 };